@@ -21,17 +21,17 @@ class TestQueue(unittest.TestCase):
         self.assertEqual(self.queue.vhost, '/')
         self.assertEqual(self.queue.credentials, pika.PlainCredentials('guest', 'guest'))
         self.assertEqual(self.queue.max_retries, 100)
-        self.assertEqual(self.queue.retry_interval, 5)
+
+    def test_repr(self):
+        self.assertEqual(repr(self.queue), "Queue('bunnymq.unittest', host='localhost', port=5672, vhost='/')")
 
     def test_bad_init(self):
         with self.assertRaises(AssertionError):
             Queue('badinput'*500)
             Queue('badinput', max_retries=-1)
-            Queue('badinput', retry_interval=-1)
 
         with self.assertRaises(ValueError):
             Queue('badinput', max_retries='x')
-            Queue('badinput', retry_interval='x')
 
     def test_len_of_new_queue(self):
         self.assertEqual(len(self.queue), 0)
@@ -40,6 +40,11 @@ class TestQueue(unittest.TestCase):
         self.queue.put(1)
         self.assertEqual(len(self.queue), 1)
 
+    def test_put_if_disconnected(self):
+        self.queue.disconnect()
+        self.queue.put(1)
+        self.assertEqual(len(self.queue), 1)
+
     def test_get(self):
         self.queue.put(1)
         item = self.queue.get()
